Struct AffidavitPayload

pub struct AffidavitPayload<Public, AccountId>
where Public: Debug + TypeInfo, AccountId: Debug + TypeInfo,
{ pub public: Public, pub rotate: AccountId, }
Unsigned payload for crate::Pallet::declare extrinsic.

  • public is the currently active affidavit key, used to authorize the affidavit declaration.
  • rotate is the next affidavit key that will be registered and rotated in as the active key for the upcoming session.

The payload is signed offchain using the active affidavit key and verified on-chain via ValidateUnsigned.

Fields

public: Public

Active affidavit public key used for authorization.

rotate: AccountId

Next affidavit key to be rotated in for the upcoming session.