pub struct ElectionPayload<Public>where
Public: Debug + TypeInfo,{
pub public: Public,
}Expand description
Unsigned payload for crate::Pallet::elect extrinsic.
The public field represents the currently active affidavit key,
which was very recently rotated during the latest affidavit declaration.
Elections require the affidavit key that was registered for the upcoming session’s affidavit window. This ensures that only authors who successfully completed affidavit declaration and key rotation are eligible to run the election.
Fields
public: PublicActive affidavit public key authorizing election execution.