pub struct AffidavitPayload<Public, AccountId>{
pub public: Public,
pub rotate: AccountId,
}Expand description
Unsigned payload for crate::Pallet::declare extrinsic.
publicis the currently active affidavit key, used to authorize the affidavit declaration.rotateis the next affidavit key that will be registered and rotated in as the active key for the upcoming session.
The payload is signed offchain using the active affidavit key and
verified on-chain via ValidateUnsigned.
Fields
public: PublicActive affidavit public key used for authorization.
rotate: AccountIdNext affidavit key to be rotated in for the upcoming session.